var classjuce_1_1UnitTestRunner =
[
    [ "TestResult", "structjuce_1_1UnitTestRunner_1_1TestResult.html", "structjuce_1_1UnitTestRunner_1_1TestResult" ],
    [ "~UnitTestRunner", "classjuce_1_1UnitTestRunner.html#a1e6f06285fe053758cbbb136a4e7c718", null ],
    [ "getNumResults", "classjuce_1_1UnitTestRunner.html#a44b3390caaa8a6b5d52b11150802ba2e", null ],
    [ "getResult", "classjuce_1_1UnitTestRunner.html#a3d0bc5c8543023b1d83387f2bba0e2b5", null ],
    [ "logMessage", "classjuce_1_1UnitTestRunner.html#adcd91a1f5eea2248f22307723e6cada6", null ],
    [ "resultsUpdated", "classjuce_1_1UnitTestRunner.html#aff7aa1c4d53abe84ee1f487101f4e0ac", null ],
    [ "runAllTests", "classjuce_1_1UnitTestRunner.html#a0185912118249a679014f9b2eb97ca99", null ],
    [ "runTests", "classjuce_1_1UnitTestRunner.html#a947b90606939bdcb855e65f1a8fe57cb", null ],
    [ "runTestsInCategory", "classjuce_1_1UnitTestRunner.html#a11d4cb718f8a40679caee0e35b712837", null ],
    [ "setAssertOnFailure", "classjuce_1_1UnitTestRunner.html#a7e4609520dd68c774c9c1f8a266ce48c", null ],
    [ "setPassesAreLogged", "classjuce_1_1UnitTestRunner.html#ab85fc06983126de406650774afd77f1d", null ],
    [ "shouldAbortTests", "classjuce_1_1UnitTestRunner.html#a2665e07ede412ce1ac4edb4ca5b56fbb", null ]
];